@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -301,7 +301,7 @@ Music::Intervals - Breakdown of named musical intervals
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -337,6 +337,9 @@ version 0.0601
   $name  = $m->by_ratio($ratio);
   $ratio = $m->by_name($interval_name);
 
+  perl -Ilib -MMusic::Intervals::Ratios -E'say $Music::Intervals::Ratios::ratio->{C}{name}'
+  # unison, perfect prime, tonic
+
   # Show all the 447 known intervals:
   perl -MData::Dumper -MMusic::Intervals::Ratios -e'print Dumper $Music::Intervals::Ratios::ratio'
 
@@ -556,14 +559,14 @@ L<Music::Intervals::Ratios> for the note and interval names.
 
 L<Music::Intervals::Numeric> for numeric-only note-intervals
 
-L<https://github.com/ology/Music/blob/master/intervals> - The predecessor to this module
-
 L<http://en.wikipedia.org/wiki/List_of_musical_intervals>
 
 L<http://en.wikipedia.org/wiki/Equal_temperament>
 
 L<http://en.wikipedia.org/wiki/Just_intonation>
 
+L<Music::Scala> - A powerful module encompassing thousands of scales and the ratios therein
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
