@@ -1,4 +1,5 @@
 package Music::Intervals::Numeric;
+$Music::Intervals::Numeric::VERSION = '0.0602';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Breakdown of numeric musical intervals
@@ -6,13 +7,13 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0201';
-
-use Moo;
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
 use Number::Fraction ();
 use Music::Intervals::Ratios;
+use Moo;
+use strictures 2;
+use namespace::clean;
 
 
 has notes     => ( is => 'ro', default => sub { [] } );
@@ -142,7 +143,7 @@ Music::Intervals::Numeric - Breakdown of numeric musical intervals
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
